@@ -1,6 +1,6 @@
 from rest_framework import serializers
 from netbox.api.serializers import NetBoxModelSerializer, WritableNestedSerializer
-from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment
+from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUser, PTWorkstation
 from django.contrib.auth.models import ContentType
 from drf_yasg.utils import swagger_serializer_method
 from netbox.api.fields import ChoiceField, ContentTypeField
@@ -135,3 +135,43 @@ class PTAppSystemAssignmentSerializer(NetBoxModelSerializer):
             instance.content_type.model_class(), prefix='Nested')
         context = {'request': self.context['request']}
         return serializer(instance.object, context=context).data
+
+
+class NestedPTUserSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:ptuevents-api:ptusers-detail'
+    )
+
+    class Meta:
+        model = PTUser
+        fields = ('id', 'display', 'url', 'name', 'description')
+
+
+class PTUserSerializer(NetBoxModelSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:ptuevents-api:ptusers-detail'
+    )
+
+    class Meta:
+        model = PTUser
+        fields = ('id', 'url', 'display', 'name', 'description')
+
+
+class NestedPTWorkstationSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:ptuevents-api:ptworkstations-detail'
+    )
+
+    class Meta:
+        model = PTWorkstation
+        fields = ('id', 'url', 'display', 'name', 'description')
+
+
+class PTWorkstationSerializer(NetBoxModelSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name='plugins-api:ptuevents-api:ptworkstations-detail'
+    )
+
+    class Meta:
+        model = PTWorkstation
+        fields = ('id', 'url', 'display', 'name', 'description')
