@@ -1,7 +1,7 @@
 from .serializers import PTAppSystemSerializer, PTAppSystemAssignmentSerializer
 from netbox.api.viewsets import NetBoxModelViewSet
-from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment
-from .serializers import PTUEventRelationSerializer, PTUEventSerializer, PTUEventAssignmentSerializer
+from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUser, PTWorkstation
+from .serializers import PTUEventRelationSerializer, PTUEventSerializer, PTUEventAssignmentSerializer, PTUserSerializer, PTWorkstationSerializer
 from .. import filtersets
 
 
@@ -33,3 +33,14 @@ class PTAppSystemAssignmentViewSet(NetBoxModelViewSet):
         'object', 'app_system')
     serializer_class = PTAppSystemAssignmentSerializer
     filterset_class = filtersets.PTAppSystemAssignmentFilterSet
+
+
+class PTUserListViewSet(NetBoxModelViewSet):
+    queryset = PTUser.objects.prefetch_related('tags')
+    serializer_class = PTUserSerializer
+
+
+class PTWorkstationListViewSet(NetBoxModelViewSet):
+    queryset = PTWorkstation.objects.prefetch_related('tags')
+    serializer_class = PTWorkstationSerializer
+
